@@ -4,10 +4,10 @@ warnings.filterwarnings("ignore")
 import os
 import pickle
 import csv 
-from .dataCleaning import *
-from .taxonomyAPI import *
-from .higherLevelAPI import *
-from .commonNameAPI import *
+from dataCleaning import *
+from taxonomyAPI import *
+from higherLevelAPI import *
+from commonNameAPI import *
 import itertools
 
 class EcoNameTranslator:
@@ -79,4 +79,15 @@ class EcoNameTranslator:
         
         with open(path+"/"+name, "w", newline="") as f:
             writer = csv.writer(f)
-            writer.writerows(csvData)
\ No newline at end of file
+            writer.writerows(csvData)
+    
+
+import time
+start_time = time.time()
+unstandardised_names = ['blackbird'] # A genus of various big cats       
+translator = EcoNameTranslator()   
+index = translator.translate(unstandardised_names)
+print(index)
+print("--- %s seconds ---" % (time.time() - start_time))
+
+# {'Panthera': ['panthera leo', 'panthera uncia', 'panthera tigris', 'panthera onca', 'panthera pardus','panthera spec']}    
\ No newline at end of file
