@@ -1,5 +1,5 @@
 from gevent import monkey as curious_george
-curious_george.patch_all(select=False)
+curious_george.patch_all(thread=False,select=False)
 import grequests 
 import itertools
 
